@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
+
 from imio.history.config import HISTORY_REVISION_NOT_VIEWABLE
 from imio.history.interfaces import IImioHistory
+from imio.prettylink.interfaces import IPrettyLink
 from plone import api
 from plone.app.layout.viewlets.content import ContentHistoryView
 from plone.app.layout.viewlets.content import DocumentBylineViewlet
@@ -42,13 +44,8 @@ class IHDocumentBylineViewlet(DocumentBylineViewlet):
 
     def show_history(self):
         """Rely on contenthistory.show_history."""
-        res = self.contenthistory.show_history()
-        if res:
-            # do not show a link to the history if we are displaying something in
-            # an overlay because history is displayed in an overlay and it does not work...
-            if 'ajax_load' in self.request:
-                res = False
-        return res
+        if super(IHDocumentBylineViewlet, self).show_history():
+            return self.contenthistory.show_history()
 
     def highlight_history_link(self):
         """
@@ -100,13 +97,13 @@ class IHContentHistoryView(ContentHistoryView):
         """ """
         return {}
 
-    def renderComments(self, event):
+    def renderComments(self, event, mimetype='text/plain'):
         """
           Render comments correctly as it is 'plain/text' and we want 'text/html'.
         """
         # prepare some data passed to translate as mappings
         mapping = event.copy()
-        mapping['event_time'] = int(event['time'])
+        mapping['event_time'] = float(event['time'])
         mapping['url'] = self.context.absolute_url()
         mapping.update(self._extra_render_comments_mapping())
         # try to translate comments before it is turned into text/html
@@ -116,7 +113,8 @@ class IHContentHistoryView(ContentHistoryView):
             domain='imio.history',
             context=self.request)
         transformsTool = api.portal.get_tool('portal_transforms')
-        data = transformsTool.convertTo('text/x-html-safe', translated)
+        data = transformsTool.convertTo(
+            'text/x-html-safe', translated, mimetype=mimetype)
         return data.getData()
 
     @memoize
@@ -200,6 +198,18 @@ class EventPreviewView(BrowserView):
         self.portal = getToolByName(self.context, 'portal_url').getPortalObject()
         self.portal_url = self.portal.absolute_url()
 
+    def may_view_historized_data(self):
+        """ """
+        return True
+
     def __call__(self, event):
         self.event = event
         return super(EventPreviewView, self).__call__(event)
+
+
+class HeaderView(BrowserView):
+    """ """
+
+    def get_title(self):
+        """ """
+        return IPrettyLink(self.context).getLink()
