@@ -6,6 +6,7 @@ from imio.history.interfaces import IImioHistory
 from imio.history.testing import IntegrationTestCase
 from imio.history.utils import add_event_to_history
 from imio.history.utils import get_all_history_attr
+from imio.history.utils import get_event_by_time
 from imio.history.utils import getLastAction
 from imio.history.utils import getLastWFAction
 from imio.history.utils import getPreviousEvent
@@ -132,6 +133,27 @@ class TestUtils(IntegrationTestCase):
         self.assertEqual(publish_action['comments'], 'Publication comment')
         self.assertEqual(getLastWFAction(doc, transition='before_last')['review_state'], 'private')
 
+    def test_getLastWFAction_ignore_previous_event_actions(self):
+        """Test utils.getLastWFAction with ignore_previous_event_actions."""
+        doc = api.content.create(type='Document',
+                                 id='doc',
+                                 container=self.portal)
+        # we are going to:
+        # publish, retract, submit, publish
+        # then get the last publish ignoring previous "submit"
+        api.content.transition(doc, 'publish', comment='Publication comment')
+        api.content.transition(doc, 'retract', comment='Retract comment')
+        api.content.transition(doc, 'submit', comment='Submit comment')
+        api.content.transition(doc, 'publish', comment='Publication2 comment')
+        action = getLastWFAction(doc, 'publish')
+        action_with_ignored_previous = getLastWFAction(
+            doc, 'publish', ignore_previous_event_actions=['submit'])
+        self.assertNotEqual(action['time'], action_with_ignored_previous['time'])
+        self.assertEqual(action['action'], 'publish')
+        self.assertEqual(action_with_ignored_previous['action'], 'publish')
+        self.assertEqual(action['comments'], 'Publication2 comment')
+        self.assertEqual(action_with_ignored_previous['comments'], 'Publication comment')
+
     def test_add_event_to_history(self):
         """Add an event to an history following an action."""
         folder = self.portal.folder
@@ -182,3 +204,13 @@ class TestUtils(IntegrationTestCase):
                          ['test_user_1_', 'test_user_1_', 'test_user_1_'])
         self.assertEqual(get_all_history_attr(doc, attr_name='comments'),
                          ['', 'Publication comment', ''])
+
+    def test_get_event_by_time(self):
+        doc = api.content.create(type='Document',
+                                 id='doc',
+                                 container=self.portal)
+        api.content.transition(doc, 'publish', comment='Publication comment')
+        api.content.transition(doc, 'retract')
+        float_event_time = float(doc.workflow_history['simple_publication_workflow'][-1]['time'])
+        self.assertEqual(get_event_by_time(doc, 'workflow', float_event_time)['action'], 'retract')
+        self.assertIsNone(get_event_by_time(doc, 'workflow', 0))
